@@ -6,6 +6,7 @@ import (
 	"github.com/jandedobbeleer/oh-my-posh/src/cache"
 	"github.com/jandedobbeleer/oh-my-posh/src/prompt"
 	"github.com/jandedobbeleer/oh-my-posh/src/runtime"
+	"github.com/jandedobbeleer/oh-my-posh/src/shell"
 	"github.com/jandedobbeleer/oh-my-posh/src/template"
 
 	"github.com/spf13/cobra"
@@ -62,6 +63,10 @@ func createPrintCmd() *cobra.Command {
 				return
 			}
 
+			if shellName == "" {
+				shellName = shell.GENERIC
+			}
+
 			flags := &runtime.Flags{
 				ConfigPath:    configFlag,
 				PWD:           pwd,
