@@ -5,7 +5,7 @@ import (
 )
 
 type Angular struct {
-	language
+	Language
 }
 
 func (a *Angular) Template() string {
@@ -22,7 +22,7 @@ func (a *Angular) Enabled() bool {
 	}
 	a.versionURLTemplate = "https://github.com/angular/angular/releases/tag/{{.Full}}"
 
-	return a.language.Enabled()
+	return a.Language.Enabled()
 }
 
 func (a *Angular) getVersion() (string, error) {
