@@ -8,7 +8,6 @@ import (
 	"github.com/jandedobbeleer/oh-my-posh/src/runtime/mock"
 
 	"github.com/stretchr/testify/assert"
-	testify_ "github.com/stretchr/testify/mock"
 )
 
 func TestSitecoreSegment(t *testing.T) {
@@ -89,8 +88,6 @@ func TestSitecoreSegment(t *testing.T) {
 		env.On("HasFiles", "sitecore.json").Return(tc.SitecoreFileExists)
 		env.On("HasFilesInDir", ".sitecore", "user.json").Return(tc.UserFileExists)
 		env.On("FileContent", path.Join(".sitecore", "user.json")).Return(tc.UserFileContent)
-		env.On("Debug", testify_.Anything)
-		env.On("Error", testify_.Anything)
 
 		props := properties.Map{
 			properties.DisplayDefault: tc.DisplayDefault,
